inspect

package
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 12, 2023 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func TableFields

func TableFields(db *sql.DB, database, table string) ([]query.Field, error)

TableFields analyzes table structure and returns slice of sortable/filterable fields.

func TablesFields

func TablesFields(db *sql.DB, database string) (map[string][]query.Field, error)

TablesFields analyzes all tables within database and returns slice of sortable/filterable fields.

Types

This section is empty.

Jump to