types

package
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 12, 2023 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsFloat

func IsFloat(v interface{}) bool

IsFloat returns true if underlying given data type can hold or produce float values.

func IsInt

func IsInt(v interface{}) bool

IsInt returns true if underlying given data type can hold or produce integer values.

func IsNullable

func IsNullable(v interface{}) bool

IsNullable return true if type of given value supports nil as valid value.

func IsNumber

func IsNumber(v interface{}) bool

IsNumber returns true if underlying given data type can hold or produce any type of number values.

func IsString

func IsString(v interface{}) bool

IsString returns true if underlying given data type can hold or produce string values.

func ToString

func ToString(v interface{}) string

ToString converts given any to string

Types

This section is empty.

Jump to