Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsFloat ¶
func IsFloat(v interface{}) bool
IsFloat returns true if underlying given data type can hold or produce float values.
func IsInt ¶
func IsInt(v interface{}) bool
IsInt returns true if underlying given data type can hold or produce integer values.
func IsNullable ¶
func IsNullable(v interface{}) bool
IsNullable return true if type of given value supports nil as valid value.
func IsNumber ¶
func IsNumber(v interface{}) bool
IsNumber returns true if underlying given data type can hold or produce any type of number values.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.